from ..db.db_entity import DbEntity
from ...named import SnakeCaseNamed

class GresEntity(DbEntity, SnakeCaseNamed):
    pass
